#
# spec file for package rinstall
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rinstall
Version:        0.2.0
Release:        bp160.1.7
Summary:        Declarative install for programs
#               If you know the license, put it's SPDX string here.
#               Alternately, you can use cargo lock2rpmprovides to help generate this.
License:        GPL-3.0-or-later
#               Select a group from this link:
#               https://en.opensuse.org/openSUSE:Package_group_guidelines
URL:            https://github.com/danyspin97/rinstall
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Source3:        macros.%{name}
BuildRequires:  cargo-packaging

%description
A helper tool that installs software and additional data into the system.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}
install -m 0644 -D -t %{buildroot}%{_rpmconfigdir}/macros.d %{SOURCE3}

%check
%{cargo_test}

%files
%doc README.md CHANGELOG.md
%{_bindir}/rinstall
%{_rpmconfigdir}/macros.d/macros.%{name}

%changelog
* Tue Apr 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix typo in description.
* Tue May 24 2022 Danilo Spinella <danilo.spinella@suse.com>
- Fix rinstall usage in macros.rinstall
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Thu May 19 2022 Danilo Spinella <danilo.spinella@suse.com>
- Fix systemd unitdir in macros.rinstall
* Thu May 19 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 0.2.0:
  * install.yml:
    + Add new `systemd-user-units` key
  * **Breaking changes**:
    + Use `XDG_DATA_HOME` as `localstatedir` in non system-wide installations
    + Use `/usr/local/lib/systemd` as systemd_unitsdir instead of
    `/usr/local/lib/systemd/system`
    + `user-config` will be installed as docs in system-wide installations
    + Move default command to an install subcommand
  * Add colored output
  * Add new `--rust-debug-target` flag
  * Small improvements to dry mode and warnings
  * Improved README.md documentation
  * Add autogenerated man pages and completions
  * Add $PROJECTDIR placeholder for rust projects
  * Take multiple packages in `uninstall` command
  * Add support for pkginfo files as argument in `uninstall`
  * Rework rinstall arguments
  * Enable system mode dependending on the flag; previously it was
    always enabled when rinstall was executed as root
  * Add --update flag to install command
  * Improved messages
  * Add elvish completions
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Wed Dec  1 2021 Danilo Spinella <danilo.spinella@suse.com>
- Initial packaging of version 0.1.1
